@@ -35,6 +35,11 @@ class Indicators(Model):
         """
         return self._phishdetect.get(API_PATH["indicators_fetch_all"])        
 
+    def disabled(self):
+        """Fetch all the indicators that are marked as disabled.
+        """
+        return self._phishdetect.get(API_PATH["indicators_disabled"])
+
     def details(self, sha256):
         """Retrieve details on a given indicator (by hash).
         :param sha256: SHA256 hash of the indicator.
